@@ -26,6 +26,9 @@ STABLE.
 import logging
 import math
 
+import gi
+gi.require_version('SugarGestures', '1.0')
+
 from gi.repository import Gdk
 from gi.repository import Gtk
 from gi.repository import GObject
